<?php
// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

/**
 * 移除管理页面页脚
 */
function jefrss_remove_footer_admin() {
    // 移除所有页脚信息
    add_filter('admin_footer_text', '__return_empty_string', 11);
    add_filter('update_footer', '__return_empty_string', 11);
}
add_action('admin_menu', 'jefrss_remove_footer_admin');

/**
 * 添加管理页面样式
 */
function jefrss_admin_styles() {
    // 只在插件页面添加
    $screen = get_current_screen();
    if (strpos($screen->id, 'jefrss-simple') !== false) {
        ?>
        <style type="text/css">
        #wpfooter {display: none !important;}
        .jefrss-status-bar {display: none !important;}
        </style>
        <?php
    }
}
add_action('admin_head', 'jefrss_admin_styles');

// 修改后台菜单
function jefrss_simple_add_menu_items() {
    // 主菜单 - 显示管理页面
    add_menu_page(
        'Jefrss Simple',
        '订阅',
        'manage_options',
        'jefrss-simple',
        'jefrss_simple_management_page',
        'dashicons-rss',
        3
    );

    // 其他子菜单
    add_submenu_page(
        'jefrss-simple',
        '站点',
        '站点',
        'manage_options',
        'jefrss-simple-sites',
        'jefrss_simple_sites_page'
    );

    add_submenu_page(
        'jefrss-simple',
        '日志',
        '日志',
        'manage_options',
        'jefrss-simple-logs',
        'jefrss_simple_logs_page'
    );

    add_submenu_page(
        'jefrss-simple',
        '主题',
        '主题',
        'manage_options',
        'jefrss-simple-themes',
        'jefrss_simple_themes_page'
    );
}
add_action('admin_menu', 'jefrss_simple_add_menu_items');

// 添加处理OPML导入的函数
function jefrss_process_opml_import() {
    if (isset($_POST['import_opml']) && isset($_FILES['opml_file'])) {
        // 验证nonce
        check_admin_referer('jefrss_import_action', 'jefrss_import_nonce');
        
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }
        
        // 处理文件上传
        $file = $_FILES['opml_file'];
        
        // 检查文件类型
        $file_ext = strtolower(pathinfo($file['name'], PATHINFO_EXTENSION));
        if (!in_array($file_ext, array('opml', 'xml'))) {
            add_settings_error(
                'jefrss_messages',
                'jefrss_import_error',
                '文件类型不支持，请上传.opml或.xml文件',
                'error'
            );
        } else if ($file['error'] !== UPLOAD_ERR_OK) {
            add_settings_error(
                'jefrss_messages',
                'jefrss_import_error',
                '文件上传失败: ' . $file['error'],
                'error'
            );
        } else {
            // 处理OPML导入
            require_once JEFRSS_PLUGIN_DIR . 'includes/opml.php';
            $importer = Jefrss_Simple_OPML::get_instance();
            $result = $importer->import($file['tmp_name']);
            
            if (is_wp_error($result)) {
                add_settings_error(
                    'jefrss_messages',
                    'jefrss_import_error',
                    '导入失败: ' . $result->get_error_message(),
                    'error'
                );
            } else {
                add_settings_error(
                    'jefrss_messages',
                    'jefrss_import_success',
                    sprintf('成功导入 %d 个订阅源', $result['imported']),
                    'success'
                );
                
                if (!empty($result['failed'])) {
                    add_settings_error(
                        'jefrss_messages',
                        'jefrss_import_warning',
                        sprintf('导入失败 %d 个订阅源', count($result['failed'])),
                        'warning'
                    );
                }
            }
        }
    }
}
add_action('admin_init', 'jefrss_process_opml_import');

// 添加这个函数来显示通知
function jefrss_display_admin_notices() {
    // 只在插件页面显示
    $screen = get_current_screen();
    if (strpos($screen->id, 'jefrss-simple') !== false) {
        // 检查是否有临时通知消息
        $notice = get_transient('jefrss_admin_notice');
        if ($notice) {
            // 显示通知
            echo '<div class="notice notice-' . esc_attr($notice['type']) . ' is-dismissible">';
            echo '<p>' . esc_html($notice['message']) . '</p>';
            echo '</div>';
            
            // 删除临时通知
            delete_transient('jefrss_admin_notice');
        }
        
        settings_errors('jefrss_messages');
    }
}
add_action('admin_notices', 'jefrss_display_admin_notices');

/**
 * 优化管理页面
 */
function jefrss_simple_management_page() {
    // 显示所有通知消息
    settings_errors('jefrss_messages');
    
    // 处理表单提交
    if (isset($_POST['submit'])) {
        check_admin_referer('jefrss_management_action', 'jefrss_management_nonce');
        
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }
        
        $manager = Jefrss_Simple_Manager::get_instance();
        
        if (isset($_POST['batch_feeds'])) {
            // 处理批量添加
            $feeds_data = array();
            $lines = explode("\n", sanitize_textarea_field($_POST['batch_feeds']));
            
            foreach ($lines as $line) {
                $parts = explode(',', $line, 2);
                if (count($parts) === 2) {
                    $feeds_data[] = array(
                        'name' => trim($parts[0]),
                        'url' => esc_url_raw(trim($parts[1]))
                    );
                }
            }
            
            $results = $manager->batch_save_feeds($feeds_data);
            
            if (!empty($results['success'])) {
                add_settings_error(
                    'jefrss_messages',
                    'jefrss_success',
                    sprintf('成功添加 %d 个订阅', count($results['success'])),
                    'success'
                );
            }
            
            if (!empty($results['failed'])) {
                foreach ($results['failed'] as $fail) {
                    add_settings_error(
                        'jefrss_messages',
                        'jefrss_error',
                        $fail['url'] . ': ' . $fail['message'],
                        'error'
                    );
                }
            }
        } else {
            // 处理单个添加
            $url = isset($_POST['rss_url']) ? esc_url_raw($_POST['rss_url']) : '';
            $name = isset($_POST['site_name']) ? sanitize_text_field($_POST['site_name']) : '';
            
            if (empty($url)) {
                add_settings_error('jefrss_messages', 'jefrss_error', 'RSS 地址不能为空', 'error');
            } else {
                $result = $manager->save_feed($url, $name);
                
                // 重定向到站点列表页面
                wp_redirect(add_query_arg(array(
                    'page' => 'jefrss-simple-sites'
                ), admin_url('admin.php')));
                exit;
            }
        }
    }
    
    // 获取当前设置
    $fetch_interval = get_option('jefrss_fetch_interval', 60);
    $fetch_count = get_option('jefrss_fetch_count', 3);
    $icon_source = get_option('jefrss_icon_source', 'local');
    
    // 显示错误/成功消息
    settings_errors('jefrss_messages');
    ?>
    <div class="wrap jefrss-admin">
        <h1 class="wp-heading-inline">RSS 订阅管理</h1>
        
        <div class="grid-container">
            <!-- 第一行 -->
            <div class="grid-row">
                <!-- 欢迎卡片 -->
                <div class="card welcome-card">
                    <div class="card-header">
                        <h2><i class="dashicons dashicons-welcome-learn-more"></i> 使用说明</h2>
                    </div>
                    <div class="card-content">
                        <div class="shortcode-info">
                            <div class="shortcode-title">
                                <i class="dashicons dashicons-shortcode"></i>
                                <span>在文章或页面中使用以下短代码显示RSS内容：</span>
                            </div>
                            <div class="shortcode-text">
                                [rss_feed article_count="30"]
                            </div>
                        </div>
                    </div>
                </div>

                <!-- 设置卡片 -->
                <div class="card settings-card">
                    <div class="card-header">
                        <h2><i class="dashicons dashicons-admin-settings"></i> 全局设置</h2>
                    </div>
                    <form method="post" action="">
                        <?php wp_nonce_field('jefrss_settings_action', 'jefrss_settings_nonce'); ?>
                        <div class="jefrss-settings-container">
                            <!-- 第一行：并排显示两个选项 -->
                            <div class="jefrss-settings-row" style="display: flex; justify-content: space-between; margin-bottom: 15px;">
                                <div class="setting-item" style="width: 48%;">
                                    <label for="fetch_interval">抓取间隔</label>
                                    <div class="setting-control">
                                        <select name="fetch_interval" id="fetch_interval" style="width: 100%;">
                                            <?php
                                            $current_interval = get_option('jefrss_fetch_interval', 180);
                                            $intervals = array(
                                                60 => '1小时',
                                                120 => '2小时',
                                                180 => '3小时',
                                                360 => '6小时',
                                                720 => '12小时',
                                                1440 => '24小时'
                                            );
                                            
                                            foreach ($intervals as $value => $label) {
                                                printf(
                                                    '<option value="%d" %s>%s</option>',
                                                    $value,
                                                    selected($current_interval, $value, false),
                                                    esc_html($label)
                                                );
                                            }
                                            ?>
                                        </select>
                                    </div>
                                </div>
                                <div class="setting-item" style="width: 48%;">
                                    <label for="fetch_count">每源文章数</label>
                                    <div class="setting-control">
                                        <select name="fetch_count" id="fetch_count" style="width: 100%;">
                                            <option value="1" <?php selected($fetch_count, 1); ?>>1篇</option>
                                            <option value="2" <?php selected($fetch_count, 2); ?>>2篇</option>
                                            <option value="3" <?php selected($fetch_count, 3); ?>>3篇</option>
                                            <option value="4" <?php selected($fetch_count, 4); ?>>4篇</option>
                                            <option value="5" <?php selected($fetch_count, 5); ?>>5篇</option>
                                        </select>
                                    </div>
                                </div>
                            </div>
                            
                            <!-- 第二行：图标来源选项 -->
                            <div class="jefrss-settings-row">
                                <div class="setting-item">
                                    <label for="icon_source">图标来源</label>
                                    <div class="setting-control">
                                        <select name="icon_source" id="icon_source" style="width: 100%;">
                                            <?php
                                            $icon_sources = array(
                                                
                                                'afmax' => 'api.afmax.cn',
                                                'favicon_im' => 'favicon.im',
                                                'cravatar' => 'cravatar.com',
                                                'favicon_h4ck' => 'favicon.h4ck.org.cn',
                                                'unavatar' => 'unavatar.io', 
                                                'ui_avatars' => '糖果色字母图标'
                                            );
                                            foreach ($icon_sources as $value => $label) {
                                                echo '<option value="' . esc_attr($value) . '" ' . selected($icon_source, $value, false) . '>' . esc_html($label) . '</option>';
                                            }
                                            ?>
                                        </select>
                                        <p class="description">根据本地网络选择图标来源，请在短代码展示页面观看效果，服务第三方提供。</p>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <input type="submit" name="save_settings" class="button button-primary" value="保存设置" style="margin-top: 10px;">
                    </form>
                </div>
            </div>

            <!-- 第二行 -->
            <div class="grid-row">
                <!-- 导入区域 -->
                <div class="card import-card">
                    <div class="card-header">
                        <h2><i class="dashicons dashicons-upload"></i> 导入订阅</h2>
                    </div>
                    <div class="card-content">
                        <form method="post" enctype="multipart/form-data" action="">
                            <?php wp_nonce_field('jefrss_import_action', 'jefrss_import_nonce'); ?>
                            <div class="drop-zone">
                                <div class="drop-zone-content">
                                    <i class="dashicons dashicons-upload"></i>
                                    <h3>选择OPML文件</h3>
                                    <p>支持.opml或.xml格式</p>
                                </div>
                                <input type="file" name="opml_file" accept=".opml,.xml" required>
                                <input type="submit" name="import_opml" class="button button-primary" value="导入">
                            </div>
                        </form>
                    </div>
                </div>

                <!-- 定时任务状态模块 -->
                <?php jefrss_display_cron_status_with_actions(); ?>
            </div>

            <!-- 添加清空文章按钮 -->
            <div class="grid-row">
                <!-- 文章管理卡片 -->
                <div class="card">
                    <div class="card-header">
                        <h2><i class="dashicons dashicons-trash"></i> 文章管理</h2>
                    </div>
                    <div class="card-content">
                        <?php jefrss_add_clear_articles_button(); ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <style>
    /* 基础样式重置和命名空间 */
    .jefrss-admin {
        box-sizing: border-box;
        padding: 0 20px; /* 减小左右padding */
    }
    
    .jefrss-admin * {
        box-sizing: inherit;
    }
    
    /* 网格布局 */
    .jefrss-admin .grid-container {
        max-width: 1200px;
        margin: 15px 0; /* 减小上下margin */
        padding: 0; /* 移除padding */
    }
    
    .jefrss-admin .grid-row {
        display: grid;
        grid-template-columns: repeat(2, 1fr);
        gap: 20px; /* 减小卡片间距 */
        margin-bottom: 20px; /* 减小行间距 */
    }
    
    /* 卡片基础样式 */
    .jefrss-admin .card {
        background: #fff;
        border-radius: 6px; /* 稍微减小圆角 */
        box-shadow: 0 1px 2px rgba(0,0,0,0.05); /* 减淡阴影 */
    }
    
    .jefrss-admin .card:hover {
        box-shadow: 0 4px 8px rgba(0,0,0,0.12);
    }
    
    .jefrss-admin .card-header {
        padding: 12px 15px; /* 减小内边距 */
        border-bottom: 1px solid #f0f0f1;
    }
    
    .jefrss-admin .card-header h2 {
        margin: 0;
        display: flex;
        align-items: center;
        gap: 6px;
        font-size: 14px; /* 减小标题字号 */
        color: #1d2327;
    }
    
    .jefrss-admin .card-content {
        padding: 15px; /* 统一内边距 */
    }
    
    /* 欢迎卡片 */
    .jefrss-admin .welcome-card .shortcode-info {
        padding: 20px;
    }
    
    .jefrss-admin .shortcode-title {
        display: flex;
        align-items: center;
        gap: 8px;
        margin-bottom: 15px;
        color: #1d2327;
    }
    
    .jefrss-admin .shortcode-text {
        font-family: monospace;
        font-size: 14px;
        margin: 15px 0;
        color: #1d2327;
    }
    
    .jefrss-admin .description {
        color: #666;
        font-style: italic;
        text-align: center;
        margin-top: 15px;
        padding-top: 15px;
        border-top: 1px solid #e2e4e7;
    }
    
    /* 设置卡片 */
    .jefrss-admin .settings-group {
        padding: 15px; /* 减小内边距 */
    }
    
    .jefrss-admin .setting-item {
        margin-bottom: 24px;
    }
    
    .jefrss-admin .setting-item:last-child {
        margin-bottom: 0;
    }
    
    .jefrss-admin .setting-item label {
        display: block;
        margin-bottom: 8px;
        font-weight: 600;
    }
    
    /* 滑块样式 */
    .jefrss-admin .setting-control input[type="range"] {
        width: 100%;
        margin: 8px 0;
    }
    
    .jefrss-admin .range-value {
        text-align: center;
        color: #666;
    }
    
    /* 数量按钮组 */
    .jefrss-admin .count-buttons {
        display: flex;
        gap: 6px; /* 减小按钮间距 */
    }
    
    .jefrss-admin .count-btn {
        flex: 1;
        padding: 6px 10px; /* 减小按钮内边距 */
        border: 1px solid #dcdcde;
        background: #f6f7f7;
        border-radius: 4px;
        cursor: pointer;
        transition: all 0.2s ease;
    }
    
    .jefrss-admin .count-btn.active {
        background: #2271b1;
        color: #fff;
        border-color: #2271b1;
    }
    
    /* 拖放区域 */
    .jefrss-admin .drop-zone {
        border: 2px dashed #c3c4c7;
        border-radius: 6px;
        padding: 20px; /* 减小内边距 */
        text-align: center;
        margin: 15px; /* 减小外边距 */
        transition: all 0.3s ease;
    }
    
    .jefrss-admin .drop-zone.dragover {
        background: #f0f6fc;
        border-color: #2271b1;
    }
    
    .jefrss-admin .drop-zone-content {
        color: #666;
    }
    
    .jefrss-admin .drop-zone-content .dashicons {
        font-size: 32px;
        width: 32px;
        height: 32px;
        margin-bottom: 12px;
    }
    
    /* 文本区域 */
    .jefrss-admin .manual-input {
        padding: 0 15px 15px; /* 统一内边距 */
    }
    
    .jefrss-admin textarea {
        width: 100%;
        min-height: 120px;
        padding: 12px;
        border: 1px solid #dcdcde;
        border-radius: 4px;
    }
    
    /* 日志表格 */
    .jefrss-admin .logs-container {
        padding: 15px; /* 统一内边距 */
    }
    
    .jefrss-admin .logs-container table {
        border-collapse: collapse;
        width: 100%;
    }
    
    .jefrss-admin .logs-container th,
    .jefrss-admin .logs-container td {
        padding: 8px 12px; /* 减小单元格内边距 */
        text-align: left;
        border-bottom: 1px solid #f0f0f1;
    }
    
    /* 响应式设计 */
    @media screen and (max-width: 782px) {
        .jefrss-admin .grid-row {
            grid-template-columns: 1fr;
        }
        
        .jefrss-admin .count-buttons {
            flex-wrap: wrap;
        }
        
        .jefrss-admin .count-btn {
            min-width: 60px;
        }
    }
    </style>
    <?php
}

/**
 * 显示日志页面
 */
function jefrss_simple_logs_page() {
    ?>
    <div class="wrap">
        <h1 class="wp-heading-inline">RSS 抓取日志</h1>
        
        <?php settings_errors('jefrss_messages'); ?>
        
        <div class="tablenav top">
            <div class="alignleft actions">
                <!-- 清空日志按钮 -->
                <form method="post" action="">
                    <input type="hidden" name="action" value="clear_logs">
                    <input type="submit" class="button" value="清空日志" 
                           onclick="return confirm('确定要清空所有日志吗？此操作不可恢复。');">
                </form>
            </div>
            <br class="clear">
        </div>
        
        <!-- 日志列表 -->
        <table class="wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th>时间</th>
                    <th>消息</th>
                </tr>
            </thead>
            <tbody>
                <?php
                $logs = get_option('jefrss_logs', array());
                $logs = array_reverse($logs); // 最新的记录显示在前面
                
                if (!empty($logs)):
                    foreach ($logs as $log):
                        $log = wp_parse_args($log, array(
                            'time' => '',
                            'message' => '',
                            'status' => ''
                        ));
                        ?>
                        <tr>
                            <td><?php echo esc_html($log['time']); ?></td>
                            <td><?php echo esc_html($log['message']); ?></td>
                        </tr>
                        <?php
                    endforeach;
                else:
                    ?>
                    <tr>
                        <td colspan="2">暂无日志</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
    <?php
}

/**
 * 处理日志页面的操作
 */
function jefrss_process_logs_actions() {
    // 处理清空日志
    if (isset($_POST['action']) && $_POST['action'] === 'clear_logs') {
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }
        
        // 清空日志
        update_option('jefrss_logs', array());
        
        // 添加一条新日志
        jefrss_add_log('日志已被管理员清空');
        
        // 重定向回日志页面
        wp_redirect(admin_url('admin.php?page=jefrss-simple-logs'));
        exit;
    }
}
add_action('admin_init', 'jefrss_process_logs_actions');

/**
 * 站点列表页面
 */
function jefrss_simple_sites_page() {
    // 处理单个操作（编辑、删除、抓取）
    if (isset($_GET['action'])) {
        $action = $_GET['action'];
        $feed_url = isset($_GET['feed']) ? urldecode($_GET['feed']) : '';
        
        if (!empty($feed_url)) {
            // 使用统一的nonce验证
            if (!check_admin_referer('jefrss_feed_action')) {
                wp_die('安全验证失败');
            }
            
            switch ($action) {
                case 'delete':
                    $manager = Jefrss_Simple_Manager::get_instance();
                    $result = $manager->delete_feed($feed_url);
                    if (!is_wp_error($result)) {
                        wp_redirect(add_query_arg('deleted', 'true', admin_url('admin.php?page=jefrss-simple-sites')));
                        exit;
                    }
                    break;
                    
                case 'fetch':
                    $manager = Jefrss_Simple_Manager::get_instance();
                    $result = $manager->fetch_feed($feed_url);
                    if (!is_wp_error($result)) {
                        wp_redirect(add_query_arg('fetched', 'true', admin_url('admin.php?page=jefrss-simple-sites')));
                        exit;
                    }
                    break;
            }
        }
    }
    
    // 处理批量操作
    if (isset($_POST['action']) && $_POST['action'] === 'delete') {
        // 使用插件特定的nonce验证
        if (!check_admin_referer('jefrss_bulk_action', 'jefrss_bulk_nonce')) {
            wp_die('安全验证失败');
        }
        
        if (!empty($_POST['feeds'])) {
            $manager = Jefrss_Simple_Manager::get_instance();
            $deleted_count = 0;
            
            foreach ($_POST['feeds'] as $url) {
                $result = $manager->delete_feed(urldecode($url));
                if ($result['success']) {
                    $deleted_count++;
                }
            }
            
            wp_redirect(add_query_arg(array(
                'page' => 'jefrss-simple-sites',
                'bulk-deleted' => $deleted_count
            ), admin_url('admin.php')));
            exit;
        }
    }
    
    // 显示消息
    if (isset($_GET['deleted'])) {
        add_settings_error('jefrss_messages', 'feed_deleted', '订阅源已删除', 'updated');
    } elseif (isset($_GET['fetched'])) {
        add_settings_error('jefrss_messages', 'feed_fetched', '订阅源已更新', 'updated');
    } elseif (isset($_GET['bulk-deleted'])) {
        $count = intval($_GET['bulk-deleted']);
        $total = isset($_GET['total']) ? intval($_GET['total']) : $count;
        if ($count === $total) {
            $message = sprintf('成功删除 %d 个订阅源', $count);
        } else {
            $message = sprintf('已处理 %d 个订阅源，成功删除 %d 个', $total, $count);
        }
        echo '<div class="updated"><p>' . esc_html($message) . '</p></div>';
    }
    
    settings_errors('jefrss_messages');
    ?>
    <div class="wrap">
        <h1 class="wp-heading-inline">订阅源管理</h1>
        <a href="<?php echo admin_url('admin.php?page=jefrss-simple-sites&action=add'); ?>" class="page-title-action">添加订阅源</a>
        
        <form id="posts-filter" method="post">
            <?php wp_nonce_field('jefrss_bulk_action', 'jefrss_bulk_nonce'); ?>
            
            <div class="tablenav top">
                <div class="alignleft actions bulkactions">
                    <label for="bulk-action-selector-top" class="screen-reader-text">选择批量操作</label>
                    <select name="action" id="bulk-action-selector-top">
                        <option value="-1">批量操作</option>
                        <option value="delete">删除</option>
                    </select>
                    <input type="submit" id="doaction" class="button action" value="应用">
                </div>
            </div>

            <table class="wp-list-table widefat fixed striped posts">
                <thead>
                    <tr>
                        <td id="cb" class="manage-column column-cb check-column">
                            <label class="screen-reader-text" for="cb-select-all-1">全选</label>
                            <input id="cb-select-all-1" type="checkbox">
                        </td>
                        <th scope="col" class="manage-column">站点名称</th>
                        <th scope="col" class="manage-column">订阅地址</th>
                        <th scope="col" class="manage-column">最后更新</th>
                        <th scope="col" class="manage-column">操作</th>
                    </tr>
                </thead>
                <tbody id="the-list">
                <?php
                $manager = Jefrss_Simple_Manager::get_instance();
                $feeds = $manager->get_feeds();
                
                if (empty($feeds)) {
                    echo '<tr><td colspan="5">暂无订阅源</td></tr>';
                } else {
                    foreach ($feeds as $url => $feed):
                ?>
                    <tr>
                        <th scope="row" class="check-column">
                            <input type="checkbox" name="feeds[]" value="<?php echo esc_attr($url); ?>">
                        </th>
                        <td><?php echo esc_html($feed['name']); ?></td>
                        <td><?php echo esc_url($url); ?></td>
                        <td>
                            <?php 
                            // 获取该源的最新文章日期
                            if (!empty($feed['items'])) {
                                $latest_date = '';
                                foreach ($feed['items'] as $article) {
                                    if (empty($latest_date) || strtotime($article['date']) > strtotime($latest_date)) {
                                        $latest_date = $article['date'];
                                    }
                                }
                                
                                if (!empty($latest_date)) {
                                    $local_time = get_date_from_gmt($latest_date);
                                    echo esc_html(human_time_diff(strtotime($local_time), current_time('timestamp'))) . '前';
                                } else {
                                    echo '从未更新';
                                }
                            } else {
                                echo '从未更新';
                            }
                            ?>
                        </td>
                        <td>
                            <a href="<?php echo jefrss_get_action_url('edit', $url); ?>" class="button button-small">编辑</a>
                            <a href="<?php echo jefrss_get_action_url('fetch', $url); ?>" class="button button-small">抓取</a>
                            <a href="<?php echo jefrss_get_action_url('delete', $url); ?>" class="button button-small delete" onclick="return confirm('确定要删除这个订阅源吗？');">删除</a>
                        </td>
                    </tr>
                <?php
                    endforeach;
                }
                ?>
                </tbody>
            </table>
        </form>
    </div>
    <?php
}

/**
 * 添加菜单注册钩子
 */
add_action('admin_menu', 'jefrss_register_subpages');

/**
 * 注册子页面
 */
function jefrss_register_subpages() {
    // 注册添加页面（但不在菜单中显示）
    add_submenu_page(
        null, // 不显示在菜单中
        '添加订阅源',
        '添加订阅源',
        'manage_options',
        'jefrss-simple-sites-add',
        'jefrss_simple_add_feed_page'
    );
    
    // 注册编辑页面（但不在菜单中显示）
    add_submenu_page(
        null,
        '编辑订阅源',
        '编辑订阅源',
        'manage_options',
        'jefrss-simple-sites-edit',
        'jefrss_simple_edit_feed_page'
    );
}

/**
 * 处理页面路由
 */
function jefrss_handle_page_routing() {
    if (!isset($_GET['page'])) {
        return;
    }

    $page = $_GET['page'];
    $action = isset($_GET['action']) ? $_GET['action'] : '';

    if ($page === 'jefrss-simple-sites') {
        switch ($action) {
            case 'add':
                wp_redirect(admin_url('admin.php?page=jefrss-simple-sites-add'));
                exit;
                
            case 'edit':
                if (isset($_GET['feed'])) {
                    wp_redirect(admin_url('admin.php?page=jefrss-simple-sites-edit&feed=' . urlencode($_GET['feed'])));
                    exit;
                }
                break;
        }
    }
}
add_action('admin_init', 'jefrss_handle_page_routing');

/**
 * 添加新订阅源页面
 */
function jefrss_simple_add_feed_page() {
    // 处理表单提交
    if (isset($_POST['add_feed'])) {
        check_admin_referer('jefrss_add_feed');
        
        $url = isset($_POST['feed_url']) ? esc_url_raw($_POST['feed_url']) : '';
        $name = isset($_POST['feed_name']) ? sanitize_text_field($_POST['feed_name']) : '';
        
        // 直接使用保存函数，只传入url和name
        $result = jefrss_simple_save_feed($url, $name);
        
        if ($result['success']) {
            wp_redirect(admin_url('admin.php?page=jefrss-simple-sites&added=true'));
            exit;
        } else {
            add_settings_error('jefrss_messages', 'feed_error', $result['message'], 'error');
        }
    }
    
    ?>
    <div class="wrap">
        <h1>添加订阅源</h1>
        
        <?php settings_errors('jefrss_messages'); ?>
        
        <form method="post" action="">
            <?php wp_nonce_field('jefrss_add_feed'); ?>
            
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="feed_url">RSS 地址</label></th>
                    <td>
                        <input type="url" name="feed_url" id="feed_url" class="regular-text" required>
                        <p class="description">输入要订阅的RSS地址</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="feed_name">站点名称</label></th>
                    <td>
                        <input type="text" name="feed_name" id="feed_name" class="regular-text">
                        <p class="description">可选，留空将使用域名作为名称</p>
                    </td>
                </tr>
            </table>
            
            <p class="submit">
                <input type="submit" name="add_feed" class="button button-primary" value="添加订阅源">
                <a href="<?php echo admin_url('admin.php?page=jefrss-simple-sites'); ?>" class="button">返回列表</a>
            </p>
        </form>
    </div>
    <?php
}

/**
 * 编辑订阅源页面
 */
function jefrss_simple_edit_feed_page() {
    if (!isset($_GET['feed'])) {
        wp_die('未指定要编辑的订阅源');
    }
    
    $url = urldecode($_GET['feed']);
    $feeds = jefrss_simple_get_feeds();
    
    if (!isset($feeds[$url])) {
        wp_die('订阅源不存在');
    }
    
    $feed = $feeds[$url];
    
    // 处理表单提交
    if (isset($_POST['save_feed'])) {
        check_admin_referer('jefrss_edit_feed');
        
        $old_url = sanitize_text_field($_POST['old_url']);
        $new_url = sanitize_text_field($_POST['feed_url']);
        $name = sanitize_text_field($_POST['feed_name']);
        $interval = intval($_POST['interval']);
        $fetch_count = intval($_POST['fetch_count']);
        
        // 如果URL改变了，先删除旧的
        if ($new_url !== $old_url) {
            unset($feeds[$old_url]);
        }
        
        // 保存更新
        $manager = Jefrss_Simple_Manager::get_instance();
        $result = $manager->edit_feed($old_url, $new_url, $name, $interval, $fetch_count);
        
        if ($result['success']) {
            // 更新成功后重定向到列表页面
            wp_redirect(admin_url('admin.php?page=jefrss-simple-sites&updated=true'));
            exit;
        } else {
            add_settings_error('jefrss_messages', 'feed_error', $result['message'], 'error');
        }
    }
    
    ?>
    <div class="wrap">
        <h1>编辑订阅源</h1>
        
        <?php settings_errors('jefrss_messages'); ?>
        
        <form method="post" action="">
            <?php wp_nonce_field('jefrss_edit_feed'); ?>
            
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="feed_url">RSS 地址</label></th>
                    <td>
                        <input type="url" name="feed_url" id="feed_url" class="regular-text" 
                               value="<?php echo esc_attr($url); ?>" required>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="feed_name">站点名称</label></th>
                    <td>
                        <input type="text" name="feed_name" id="feed_name" class="regular-text" 
                               value="<?php echo esc_attr($feed['name']); ?>">
                        <p class="description">可选，留空将使用域名作为名称</p>
                    </td>
                </tr>
            </table>
            
            <p class="submit">
                <input type="submit" name="save_feed" class="button button-primary" value="保存更改">
                <a href="<?php echo admin_url('admin.php?page=jefrss-simple-sites'); ?>" class="button">返回列表</a>
            </p>
        </form>
    </div>
    <?php
}

/**
 * 添加主题设置页面
 */
function jefrss_simple_themes_page() {
    // 处理主题保存
    if (isset($_POST['submit']) && isset($_POST['jefrss_themes_nonce'])) {
        if (!wp_verify_nonce($_POST['jefrss_themes_nonce'], 'jefrss_themes_action')) {
            wp_die('安全检查失败');
        }
        
        // 保存主题选择
        if (isset($_POST['selected_theme'])) {
            $selected_theme = sanitize_text_field($_POST['selected_theme']);
            update_option('jefrss_selected_theme', $selected_theme);
            add_settings_error('jefrss_messages', 'jefrss_theme_updated', '主题已更新', 'updated');
        }
    }
    
    // 获取当前主题
    $current_theme = get_option('jefrss_selected_theme', 'default');
    
    // 显示消息
    settings_errors('jefrss_messages');
    ?>
    <div class="wrap jefrss-admin">
        <h1>RSS 展示主题</h1>
        
        <form method="post" action="">
            <?php wp_nonce_field('jefrss_themes_action', 'jefrss_themes_nonce'); ?>
            <div class="jefrss-themes-grid">
                <?php
                $theme_manager = Jefrss_Theme_Manager::get_instance();
                $themes = $theme_manager->get_available_themes();
                
                foreach ($themes as $theme_id => $theme) {
                    ?>
                    <label for="theme_<?php echo esc_attr($theme_id); ?>" 
                           class="jefrss-theme-card">
                        <input type="radio" 
                               id="theme_<?php echo esc_attr($theme_id); ?>"
                               name="selected_theme" 
                               value="<?php echo esc_attr($theme_id); ?>" 
                               <?php checked($current_theme, $theme_id); ?> 
                               style="position: absolute; opacity: 0;">
                        <div class="theme-info">
                            <h3><?php echo esc_html($theme['name']); ?></h3>
                            <p><?php echo esc_html($theme['description']); ?></p>
                            <small>参考: <?php echo esc_html($theme['reference']); ?></small>
                        </div>
                    </label>
                    <?php
                }
                ?>
            </div>
            <?php submit_button('保存设置'); ?>
        </form>
    </div>

    <style>
    .jefrss-themes-grid {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
        gap: 20px;
        margin: 20px 0;
    }
    
    .jefrss-theme-card {
        background: #fff;
        border: 1px solid #ddd;
        border-radius: 8px;
        cursor: pointer;
        transition: all 0.2s ease;
        padding: 20px;
        display: block;
        position: relative;
    }
    
    /* 新的选中样式 */
    .jefrss-theme-card input[type="radio"]:checked + .theme-info h3 {
        color: #2271b1;
    }
    
    .jefrss-theme-card input[type="radio"]:checked {
        outline: none;
    }
    
    .jefrss-theme-card:has(input[type="radio"]:checked) {
        border-color: #2271b1;
        box-shadow: 0 0 0 1px #2271b1;
        background: #f0f7ff;
    }
    
    .jefrss-theme-card:hover {
        transform: translateY(-2px);
        box-shadow: 0 2px 8px rgba(0,0,0,0.1);
    }
    
    .theme-info {
        padding: 0;
    }
    
    .theme-info h3 {
        margin: 0 0 10px;
        font-size: 16px;
        transition: color 0.2s ease;
    }
    
    .theme-info p {
        margin: 0 0 10px;
        color: #666;
        font-size: 14px;
    }
    
    .theme-info small {
        color: #999;
        font-size: 12px;
    }
    </style>
    <?php
}

/**
 * 处理设置保存
 */
function jefrss_handle_settings_save() {
    // 检查是否点击了保存设置按钮
    if (!isset($_POST['save_settings'])) {
        return;
    }
    
    // 验证nonce
    check_admin_referer('jefrss_settings_action', 'jefrss_settings_nonce');
    
    if (!current_user_can('manage_options')) {
        wp_die('权限不足');
    }
    
    // 保存更新间隔
    $interval = isset($_POST['fetch_interval']) ? absint($_POST['fetch_interval']) : 180;
    update_option('jefrss_fetch_interval', $interval);
    
    // 保存每源文章数
    $fetch_count = isset($_POST['fetch_count']) ? absint($_POST['fetch_count']) : 3;
    update_option('jefrss_fetch_count', $fetch_count);
    
    // 保存图标来源
    $icon_source = isset($_POST['icon_source']) ? sanitize_text_field($_POST['icon_source']) : 'local';
    $old_icon_source = get_option('jefrss_icon_source', 'local');
    update_option('jefrss_icon_source', $icon_source);
    
    // 如果图标来源改变，标记需要更新图标
    if ($icon_source !== $old_icon_source) {
        update_option('jefrss_icon_source_changed', true);
    }
    
    // 重置定时任务，但不立即执行
    global $jefrss_simple;
    if (isset($jefrss_simple)) {
        $jefrss_simple->setup_scheduled_task_only($interval);
    }
    
    // 添加成功消息
    add_settings_error(
        'jefrss_messages',
        'settings_updated',
        '设置已保存',
        'updated'
    );
    
    // 如果需要立即抓取，使用wp_schedule_single_event安排一个即时任务
    if (isset($jefrss_simple)) {
        wp_schedule_single_event(time(), 'jefrss_background_fetch');
    }
}
add_action('admin_init', 'jefrss_handle_settings_save');

/**
 * 处理立即抓取请求
 */
function jefrss_process_fetch_feed() {
    // 处理单个源抓取
    if (isset($_GET['action']) && $_GET['action'] === 'fetch' && isset($_GET['feed'])) {
        // 修改 nonce 检查
        check_admin_referer('jefrss_feed_action'); // 使用统一的 nonce 名称
        
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }
        
        $url = urldecode($_GET['feed']);
        $result = jefrss_execute_single_feed_task($url);
        
        if (!$result['success']) {
            add_settings_error(
                'jefrss_messages',
                'jefrss_fetch_error',
                '抓取失败: ' . $result['message'],
                'error'
            );
        } else {
            add_settings_error(
                'jefrss_messages',
                'jefrss_fetch_success',
                sprintf('抓取成功，新增 %d 篇文章', $result['new_count']),
                'success'
            );
        }
        
        wp_redirect(admin_url('admin.php?page=jefrss-simple-sites'));
        exit;
    }
}
add_action('admin_init', 'jefrss_process_fetch_feed');

/**
 * 显示定时任务状态
 */
function jefrss_display_cron_status_with_actions() {
    $status = jefrss_get_cron_status();
    if (!isset($status['status'])) {
        $status['status'] = '空闲';  // 设置默认状态
    }
    ?>
    <div class="card cron-status-card">
        <div class="card-header">
            <h2><i class="dashicons dashicons-clock"></i> 定时任务状态</h2>
        </div>
        <div class="card-content">
            <table class="widefat">
                <tbody>
                <tr>
                    <th>当前状态</th>
                    <td><span class="status-badge <?php echo esc_attr($status['status'] === '空闲' ? 'idle' : 'running'); ?>">
                        <?php echo esc_html($status['status']); ?>
                    </span></td>
                </tr>
                <?php if ($status['is_locked']): ?>
                <tr>
                    <th>开始时间</th>
                    <td><?php echo esc_html($status['lock_time']); ?></td>
                </tr>
                <?php endif; ?>
                <tr>
                    <th>下次执行</th>
                    <td><?php echo $status['next_run'] ? esc_html($status['next_run']) : '未设置'; ?></td>
                </tr>
                <tr>
                    <th>更新间隔</th>
                    <td><?php echo esc_html($status['interval']); ?>时间</td>
                </tr>
                </tbody>
            </table>
            
            <div class="cron-actions">
                <div class="action-buttons">
                    <form method="post" action="" class="action-form">
                        <?php wp_nonce_field('jefrss_refresh_action', 'jefrss_refresh_nonce'); ?>
                        <input type="submit" 
                               name="jefrss_refresh_now" 
                               class="button button-primary" 
                               value="立即抓取"
                               <?php echo jefrss_get_fetch_lock() ? 'disabled' : ''; ?>>
                        <?php if (jefrss_get_fetch_lock()): ?>
                            <span class="description">抓取任务正在进行中...</span>
                        <?php endif; ?>
                    </form>
                    
                    <form method="post" action="" class="action-form">
                        <?php wp_nonce_field('jefrss_reset_schedule'); ?>
                        <input type="submit" name="jefrss_reset_schedule" 
                            class="button" 
                            value="重置定时">
                    </form>
                </div>
            </div>
        </div>
    </div>
    <style>
    .jefrss-admin .cron-status-card table {
        margin-bottom: 20px;
        border: none;
    }
    
    .jefrss-admin .cron-status-card th,
    .jefrss-admin .cron-status-card td {
        padding: 10px 0;
        border: none;
        border-bottom: 1px solid #f0f0f1;
        font-size: 13px;
    }
    
    .jefrss-admin .cron-status-card th {
        width: 100px;
        color: #646970;
        font-weight: normal;
    }
    
    .jefrss-admin .cron-status-card .status-badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 3px;
        font-size: 12px;
    }
    
    .jefrss-admin .cron-status-card .status-badge.running {
        background-color: #e5f5fa;
        color: #0073aa;
    }
    
    .jefrss-admin .cron-status-card .status-badge.idle {
        background-color: #f0f0f1;
        color: #646970;
    }
    
    .jefrss-admin .cron-status-card .action-buttons {
        display: flex;
        gap: 10px;
        justify-content: flex-start;
    }
    
    .jefrss-admin .cron-status-card .action-form {
        margin: 0;
    }
    
    .jefrss-admin .cron-status-card .button {
        min-width: 100px;
    }
    </style>
    <?php
}

function jefrss_handle_reset_schedule() {
    if (!isset($_POST['jefrss_reset_schedule'])) {
        return;
    }
    
    check_admin_referer('jefrss_reset_schedule');
    
    if (!current_user_can('manage_options')) {
        wp_die('权限不足');
    }
    
    global $jefrss_simple;
    $interval = get_option('jefrss_fetch_interval', 180);
    $jefrss_simple->setup_scheduled_task($interval);
    
    add_settings_error(
        'jefrss_messages',
        'schedule_reset',
        '定时任务已重置',
        'updated'
    );
}
add_action('admin_init', 'jefrss_handle_reset_schedule');

/**
 * 显示设置页面
 */
function jefrss_simple_settings_page() {
    ?>
    <div class="wrap">
        <h1>RSS 订阅设置</h1>
        
        <form method="post" action="">
            <?php wp_nonce_field('jefrss_save_settings'); ?>
            
            <table class="form-table">
                <tr>
                    <th scope="row">更新间隔</th>
                    <td>
                        <select name="fetch_interval" id="fetch_interval">
                            <?php
                            $current_interval = get_option('jefrss_fetch_interval', 180);
                            $intervals = array(
                                60 => '1小时',
                                120 => '2小时',
                                180 => '3小时',
                                360 => '6小时',
                                720 => '12小时',
                                1440 => '24小时'
                            );
                            
                            foreach ($intervals as $value => $label) {
                                printf(
                                    '<option value="%d" %s>%s</option>',
                                    $value,
                                    selected($current_interval, $value, false),
                                    esc_html($label)
                                );
                            }
                            ?>
                        </select>
                    </td>
                </tr>
            </table>
            
            <p class="submit">
                <input type="submit" name="jefrss_save_settings" class="button button-primary" value="保存设置">
            </p>
        </form>
    </div>
    <?php
}

// 在管理页面添加清空文章按钮
function jefrss_add_clear_articles_button() {
    ?>
    <div class="clear-articles-section" style="margin-top: 20px;">
        <form method="post" action="" onsubmit="return confirm('确定要清空所有文章吗？这个操作不可撤销。');">
            <?php wp_nonce_field('jefrss_clear_articles_action', 'jefrss_clear_articles_nonce'); ?>
            <input type="submit" name="clear_articles" class="button button-secondary" value="清空所有文章">
        </form>
    </div>
    <?php
}

// 处理清空文章的操作
function jefrss_handle_clear_articles() {
    if (!isset($_POST['clear_articles'])) {
        return;
    }
    
    // 验证nonce
    check_admin_referer('jefrss_clear_articles_action', 'jefrss_clear_articles_nonce');
    
    if (!current_user_can('manage_options')) {
        wp_die('权限不足');
    }
    
    // 获取所有订阅源
    $feeds = get_option('jefrss_feeds', array());
    
    // 清空每个订阅源的文章
    foreach ($feeds as $url => &$feed) {
        $feed['items'] = array();
    }
    
    // 保存更新后的数据
    update_option('jefrss_feeds', $feeds);
    
    // 清除缓存
    global $wpdb;
    $wpdb->query(
        $wpdb->prepare(
            "DELETE FROM $wpdb->options WHERE option_name LIKE %s OR option_name LIKE %s",
            $wpdb->esc_like('_transient_jefrss_') . '%',
            $wpdb->esc_like('_transient_timeout_jefrss_') . '%'
        )
    );
    
    add_settings_error(
        'jefrss_messages',
        'articles_cleared',
        '所有文章已清空',
        'updated'
    );
}
add_action('admin_init', 'jefrss_handle_clear_articles');

// 修改消息显示函数
function jefrss_admin_notices() {
    if (isset($_GET['error'])) {
        switch ($_GET['error']) {
            case 'no_items':
                echo '<div class="error"><p>请选择要删除的订阅源</p></div>';
                break;
            case 'no_action':
                echo '<div class="error"><p>请选择要执行的操作</p></div>';
                break;
        }
    } elseif (isset($_GET['bulk-deleted'])) {
        $count = intval($_GET['bulk-deleted']);
        $total = isset($_GET['total']) ? intval($_GET['total']) : $count;
        if ($count === $total) {
            $message = sprintf('成功删除 %d 个订阅源', $count);
        } else {
            $message = sprintf('已处理 %d 个订阅源，成功删除 %d 个', $total, $count);
        }
        echo '<div class="updated"><p>' . esc_html($message) . '</p></div>';
    }
}

// 修改单个操作的nonce
function jefrss_get_action_url($action, $url) {
    return wp_nonce_url(
        admin_url('admin.php?page=jefrss-simple-sites&action=' . $action . '&feed=' . urlencode($url)),
        'jefrss_feed_action'  // 使用统一的nonce名称
    );
}

/**
 * 添加管理页面JS
 */
function jefrss_admin_enqueue_scripts($hook) {
    if (strpos($hook, 'jefrss-simple-sites') !== false) {
        // 在页面底部输出内联JS
        add_action('admin_footer', 'jefrss_output_admin_js');
    }
}
add_action('admin_enqueue_scripts', 'jefrss_admin_enqueue_scripts');

/**
 * 输出管理页面JS
 */
function jefrss_output_admin_js() {
    // 传递必要的数据
    $js_data = array(
        'ajaxurl' => admin_url('admin-ajax.php'),
        'nonce' => wp_create_nonce('jefrss_feed_action'),
        'confirmMsg' => '确定要删除选中的订阅源吗？',
        'errorMsg' => '请至少选择一个订阅源'
    );
    ?>
    <script type="text/javascript">
    (function($) {
        'use strict';
        
        // 创建一个闭包空间
        const JefRssAdmin = {
            init: function() {
                this.bindEvents();
            },
            
            bindEvents: function() {
                $('#doaction').on('click', (e) => {
                    e.preventDefault();
                    this.handleBulkAction();
                });
            },
            
            handleBulkAction: function() {
                const action = $('#bulk-action-selector-top').val();
                if (action === 'delete') {
                    this.handleBulkDelete();
                }
            },
            
            handleBulkDelete: function() {
                // 获取选中的项目
                const selectedFeeds = $('input[name="feeds[]"]:checked').map(function() {
                    return $(this).val();
                }).get();
                
                // 检查是否有选中项
                if (selectedFeeds.length === 0) {
                    alert(<?php echo json_encode($js_data['errorMsg']); ?>);
                    return;
                }
                
                // 确认删除
                if (!confirm(<?php echo json_encode($js_data['confirmMsg']); ?>)) {
                    return;
                }
                
                // 发送AJAX请求
                $.ajax({
                    url: <?php echo json_encode($js_data['ajaxurl']); ?>,
                    type: 'POST',
                    data: {
                        action: 'jefrss_bulk_delete_feeds',
                        feeds: selectedFeeds,
                        _wpnonce: <?php echo json_encode($js_data['nonce']); ?>
                    },
                    beforeSend: () => {
                        // 显示加载状态
                        $('#doaction').prop('disabled', true);
                    },
                    success: (response) => {
                        if (response.success) {
                            // 刷新页面显示结果
                            window.location.reload();
                        } else {
                            alert(response.data.message || '操作失败');
                        }
                    },
                    error: () => {
                        alert('请求失败，请重试');
                    },
                    complete: () => {
                        $('#doaction').prop('disabled', false);
                    }
                });
            }
        };
        
        // 初始化
        $(document).ready(() => {
            JefRssAdmin.init();
        });
        
    })(jQuery);
    </script>
    <?php
}

/**
 * 处理批量删除的AJAX请求
 */
function jefrss_handle_bulk_delete_ajax() {
    // 检查nonce
    check_ajax_referer('jefrss_feed_action');
    
    // 检查权限
    if (!current_user_can('manage_options')) {
        wp_send_json_error(array('message' => '权限不足'));
        return;
    }
    
    // 检查参数
    if (!isset($_POST['feeds']) || !is_array($_POST['feeds'])) {
        wp_send_json_error(array('message' => '参数错误'));
        return;
    }
    
    $feeds = array_map('esc_url_raw', $_POST['feeds']);
    $result = jefrss_simple_batch_delete_feeds($feeds);
    
    if ($result['success']) {
        wp_send_json_success(array(
            'message' => sprintf('成功删除 %d 个订阅源', count($feeds))
        ));
    } else {
        wp_send_json_error(array(
            'message' => $result['message']
        ));
    }
}
add_action('wp_ajax_jefrss_bulk_delete_feeds', 'jefrss_handle_bulk_delete_ajax');