<?php
class Jefrss_Feeds_List_Table extends WP_List_Table {
    
    public function __construct() {
        parent::__construct(array(
            'singular' => 'feed',
            'plural'   => 'feeds',
            'ajax'     => false
        ));
    }
    
    public function prepare_items() {
        $manager = Jefrss_Simple_Manager::get_instance();
        $feeds = $manager->get_feeds();
        
        $this->items = array();
        foreach ($feeds as $url => $feed) {
            $this->items[] = array(
                'id' => $url,
                'name' => $feed['name'],
                'url' => $url,
                'items' => isset($feed['items']) ? $feed['items'] : array()
            );
        }
        
        $this->_column_headers = array(
            $this->get_columns(),
            array(),
            $this->get_sortable_columns()
        );
    }
    
    public function get_columns() {
        return array(
            'cb'          => '<input type="checkbox" />',
            'name'        => '站点名称',
            'url'         => '订阅地址',
            'last_update' => '最后更新',
            'actions'     => '操作'
        );
    }
    
    public function column_cb($item) {
        return sprintf(
            '<input type="checkbox" name="feed[]" value="%s" />', 
            $item['id']
        );
    }
    
    public function column_name($item) {
        return esc_html($item['name']);
    }
    
    public function column_url($item) {
        return esc_url($item['url']);
    }
    
    public function column_last_update($item) {
        $feeds = jefrss_simple_get_feeds();
        $feed = isset($feeds[$item['url']]) ? $feeds[$item['url']] : array();
        
        // 获取该源的最新文章日期
        if (!empty($feed['items'])) {
            $latest_date = '';
            foreach ($feed['items'] as $article) {
                if (empty($latest_date) || strtotime($article['date']) > strtotime($latest_date)) {
                    $latest_date = $article['date'];
                }
            }
            
            if (!empty($latest_date)) {
                $local_time = get_date_from_gmt($latest_date);
                return human_time_diff(strtotime($local_time), current_time('timestamp')) . '前';
            }
        }
        
        return '从未更新';
    }
    
    public function column_actions($item) {
        $actions = array(
            'edit' => sprintf(
                '<a href="%s" class="button button-small">编辑</a>',
                wp_nonce_url(admin_url('admin.php?page=jefrss-simple-sites&action=edit&feed=' . urlencode($item['id'])), 'jefrss_feed_action')
            ),
            'fetch' => sprintf(
                '<a href="%s" class="button button-small">抓取</a>',
                wp_nonce_url(admin_url('admin.php?page=jefrss-simple-sites&action=fetch&feed=' . urlencode($item['id'])), 'jefrss_feed_action')
            ),
            'delete' => sprintf(
                '<a href="%s" class="button button-small delete" onclick="return confirm(\'确定要删除这个订阅源吗？\');">删除</a>',
                wp_nonce_url(admin_url('admin.php?page=jefrss-simple-sites&action=delete&feed=' . urlencode($item['id'])), 'jefrss_feed_action')
            )
        );
        
        return implode(' ', $actions);
    }
    
    public function get_bulk_actions() {
        return array(
            'delete' => '删除'
        );
    }
    
    public function process_bulk_action() {
        if ('delete' === $this->current_action()) {
            $feeds = isset($_POST['feed']) ? $_POST['feed'] : array();
            if (!empty($feeds)) {
                check_admin_referer('bulk-' . $this->_args['plural']);
                
                $manager = Jefrss_Simple_Manager::get_instance();
                $deleted = 0;
                
                foreach ($feeds as $feed) {
                    $result = $manager->delete_feed($feed);
                    if (!is_wp_error($result)) {
                        $deleted++;
                    }
                }
                
                wp_redirect(add_query_arg(
                    array(
                        'page' => 'jefrss-simple-sites',
                        'deleted' => $deleted
                    ),
                    admin_url('admin.php')
                ));
                exit;
            }
        }
    }
} 