<?php
// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

// 防止类重复定义
if (!class_exists('Jefrss_Simple')):

/**
 * RSS 简单类
 */
class Jefrss_Simple {
    /**
     * 注册自定义的定时任务间隔
     */
    public function add_cron_schedules($schedules) {
        // 使用传入的间隔时间
        $interval = intval(get_option('jefrss_fetch_interval', 180));
        
        $intervals = array(
            'jefrss_custom' => array(
                'interval' => $interval * 60, // 转换为秒
                'display' => sprintf('每 %d 分钟', $interval)
            )
        );
        
        return array_merge($schedules, $intervals);
    }

    /**
     * 设置定时任务
     * @param int $interval 间隔时间（分钟）
     */
    public function setup_scheduled_task($interval) {
        // 清除所有现有的定时任务
        wp_clear_scheduled_hook('jefrss_scheduled_fetch');
        wp_clear_scheduled_hook('jefrss_simple_cron_hook');
        
        // 保存间隔时间到选项
        update_option('jefrss_fetch_interval', intval($interval));
        
        // 计算下次执行时间（避免立即执行）
        $next_run = strtotime('+' . $interval . ' minutes');
        
        // 使用wp_schedule_event设置重复任务
        wp_schedule_event($next_run, 'jefrss_custom', 'jefrss_scheduled_fetch');
        
        // 记录下次执行时间
        update_option('jefrss_next_scheduled_time', wp_next_scheduled('jefrss_scheduled_fetch'));
        
        // 记录设置日志
        jefrss_add_log(sprintf('定时任务已设置，间隔：%d 分钟，下次执行：%s', 
            $interval, 
            get_date_from_gmt(date('Y-m-d H:i:s', $next_run))
        ));
    }
    
    /**
     * 清除定时任务
     */
    private function clear_scheduled_task() {
        wp_clear_scheduled_hook('jefrss_scheduled_fetch');
        delete_option('jefrss_next_scheduled_time');
    }
    
    /**
     * 执行抓取任务
     */
    public function execute_fetch_task() {
        // 使用统一的抓取入口
        return jefrss_execute_fetch_task();
    }
    
    /**
     * 检查是否正在抓取
     */
    private function is_fetching() {
        return (bool)get_transient('jefrss_is_fetching');
    }
    
    /**
     * 设置抓取锁
     */
    private function set_fetch_lock() {
        set_transient('jefrss_is_fetching', time(), 10 * MINUTE_IN_SECONDS);
    }
    
    /**
     * 释放抓取锁
     */
    private function release_fetch_lock() {
        delete_transient('jefrss_is_fetching');
    }

    public function register_hooks() {
        // 注册定时任务执行钩子
        add_action('jefrss_scheduled_fetch', array($this, 'execute_fetch_task'));
        // 注册自定义调度间隔
        add_filter('cron_schedules', array($this, 'add_cron_schedules'));
    }

    public function __construct() {
        $this->register_hooks();
    }

    /**
     * 只设置定时任务，不执行抓取
     * @param int $interval 间隔时间（分钟）
     */
    public function setup_scheduled_task_only($interval) {
        // 保存间隔时间到选项
        update_option('jefrss_fetch_interval', intval($interval));
        
        // 清除现有定时任务
        $this->clear_scheduled_task();
        
        // 使用wp_schedule_event设置重复任务
        wp_schedule_event(time(), 'jefrss_custom', 'jefrss_scheduled_fetch');
        
        // 记录下次执行时间
        update_option('jefrss_next_scheduled_time', wp_next_scheduled('jefrss_scheduled_fetch'));
    }
}

endif; // class_exists check 