<?php
/*
Plugin Name: Jefrss Simple
Plugin URI: https://www.jeffer.xyz/jefrss-simple
Description: 一个轻量级的 RSS 订阅插件，支持多种主题展示和自动抓取
Version: 1.0.0
Author: Jeffer.Z
Author URI: https://www.jeffer.xyz
License: GPL v2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: jefrss-simple
*/

// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

// 定义插件常量
define('JEFRSS_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('JEFRSS_PLUGIN_URL', plugins_url('', __FILE__));
define('JEFRSS_DATA_FILE', JEFRSS_PLUGIN_DIR . 'data/jefrss.json');
define('JEFRSS_ICONS_DIR', JEFRSS_PLUGIN_DIR . 'icons/');
define('JEFRSS_VERSION', '1.0.0');
define('JEFRSS_LOGS_DIR', JEFRSS_PLUGIN_DIR . 'logs/');

// 加载必要文件的顺序需要调整
require_once JEFRSS_PLUGIN_DIR . 'includes/functions.php';  // 核心函数先加载
require_once JEFRSS_PLUGIN_DIR . 'includes/class-jefrss-simple.php';  // 基础类
require_once JEFRSS_PLUGIN_DIR . 'includes/class-jefrss-simple-manager.php';  // 管理类依赖基础类
require_once JEFRSS_PLUGIN_DIR . 'includes/theme.php';      // 主题管理依赖核心类
require_once JEFRSS_PLUGIN_DIR . 'includes/admin.php';      // 管理界面依赖以上所有
require_once JEFRSS_PLUGIN_DIR . 'includes/shortcode.php';  // 短代码依赖核心类
require_once JEFRSS_PLUGIN_DIR . 'includes/opml.php';       // OPML依赖管理类
require_once JEFRSS_PLUGIN_DIR . 'includes/articles.php';   // 文章模块依赖管理类



// 插件激活时的处理
register_activation_hook(__FILE__, 'jefrss_simple_activate');
function jefrss_simple_activate() {
    // 检查目录权限
    $dirs = array(
        JEFRSS_PLUGIN_DIR . 'data',
        JEFRSS_ICONS_DIR,
        JEFRSS_PLUGIN_DIR . 'logs'  // 添加日志目录
    );
    
    foreach ($dirs as $dir) {
        if (!file_exists($dir)) {
            if (!wp_mkdir_p($dir)) {
                wp_die('无法创建目录: ' . $dir);
            }
            chmod($dir, 0755);
        }
    }
    
    // 检查数据文件权限
    if (!file_exists(JEFRSS_DATA_FILE)) {
        if (file_put_contents(JEFRSS_DATA_FILE, json_encode(array())) === false) {
            wp_die('无法创建数据文件');
        }
        chmod(JEFRSS_DATA_FILE, 0644);
    }

    // 设置定时任务
    if (!wp_next_scheduled('jefrss_simple_cron_hook')) {
        wp_schedule_event(time(), 'hourly', 'jefrss_simple_cron_hook');
    }
}

// 插件卸载时的处理
register_uninstall_hook(__FILE__, 'jefrss_simple_uninstall');
function jefrss_simple_uninstall() {
    // 删除所有插件数据
    delete_option('jefrss_feeds');
    delete_option('jefrss_logs');
    delete_option('jefrss_selected_theme');
    delete_option('jefrss_icon_source');
    delete_option('jefrss_pending_icons');
    delete_option('jefrss_is_fetching');
    
    // 删除所有图标文件
    if (is_dir(JEFRSS_ICONS_DIR)) {
        $icons = glob(JEFRSS_ICONS_DIR . '*.{png,ico}', GLOB_BRACE);
        if (is_array($icons)) {
            foreach ($icons as $icon) {
                @unlink($icon);
            }
        }
    }
    
    // 删除目录
    @rmdir(JEFRSS_ICONS_DIR);
    @rmdir(JEFRSS_LOGS_DIR);
}

// 插件停用时的处理
register_deactivation_hook(__FILE__, 'jefrss_simple_deactivate');
function jefrss_simple_deactivate() {
    // 清除定时任务
    wp_clear_scheduled_hook('jefrss_simple_cron_hook');
    wp_clear_scheduled_hook('jefrss_fetch_favicon_hook');
    
    // 记录停用日志
    if (class_exists('Jefrss_Simple_Manager')) {
        $manager = Jefrss_Simple_Manager::get_instance();
        $manager->log_system_event('插件已停用');
    }
}

// 注册前端资源
function jefrss_simple_enqueue_scripts() {
    if (!is_admin()) {
        wp_enqueue_style(
            'jefrss-simple-css', 
            JEFRSS_PLUGIN_URL . '/css/jefrss-simple.css',
            array(),
            JEFRSS_VERSION
        );
    }
}
add_action('wp_enqueue_scripts', 'jefrss_simple_enqueue_scripts');

// 在插件初始化时添加
// 确保 jefrss_manager 实例已经初始化
function jefrss_init_plugin() {
    global $jefrss_manager, $jefrss_simple;

    if (!isset($GLOBALS['jefrss_manager']) && class_exists('Jefrss_Simple_Manager')) {
        $GLOBALS['jefrss_manager'] = Jefrss_Simple_Manager::get_instance();
        $jefrss_manager = $GLOBALS['jefrss_manager'];
    }
    
    // 初始化基础类
    if (!isset($GLOBALS['jefrss_simple']) && class_exists('Jefrss_Simple')) {
        $GLOBALS['jefrss_simple'] = new Jefrss_Simple();
        $jefrss_simple = $GLOBALS['jefrss_simple'];
    }
}
add_action('init', 'jefrss_init_plugin', 5); // 优先级设为5，确保早期初始化

// 在使用全局变量之前声明
global $jefrss_manager;

// 添加图标获取钩子
add_action('jefrss_fetch_favicon_hook', array($GLOBALS['jefrss_manager'], 'async_fetch_favicon'));

// 在插件列表页添加设置链接
function jefrss_simple_plugin_action_links($links) {
    $settings_link = '<a href="' . admin_url('admin.php?page=jefrss-simple') . '">' . __('设置', 'jefrss-simple') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'jefrss_simple_plugin_action_links');

// 添加插件元信息链接
function jefrss_simple_plugin_meta_links($links, $file) {
    if (plugin_basename(__FILE__) === $file) {
        $links[] = '<a href="https://www.jeffer.xyz" target="_blank">作者主页</a>';
        $links[] = '<a href="https://www.jeffer.xyz/jefrss-simple" target="_blank">插件文档</a>';
    }
    return $links;
}
add_filter('plugin_row_meta', 'jefrss_simple_plugin_meta_links', 10, 2);


// 修改管理界面样式加载逻辑
function jefrss_simple_admin_styles() {
    // 获取当前页面
    $screen = get_current_screen();
    
    // 只在插件相关页面加载样式
    if (isset($_GET['page']) && strpos($_GET['page'], 'jefrss-simple') === 0) {
        wp_enqueue_style(
            'jefrss-simple-admin-css',
            JEFRSS_PLUGIN_URL . '/css/jefrss-simple-admin.css',
            array(),
            JEFRSS_VERSION
        );
    }
}
add_action('admin_enqueue_scripts', 'jefrss_simple_admin_styles'); 

// 添加单个订阅源抓取钩子
add_action('jefrss_single_feed_fetch_hook', function($feed_url) {
    if (class_exists('Jefrss_Simple_Manager')) {
        $manager = Jefrss_Simple_Manager::get_instance();
        $result = $manager->fetch_feed($feed_url);
        
        if (is_wp_error($result)) {
            jefrss_add_log('后台抓取失败: ' . $feed_url . ' - ' . $result->get_error_message());
        } else {
            jefrss_add_log('后台抓取成功: ' . $feed_url);
        }
    }
});

// 添加立即抓取钩子
add_action('jefrss_immediate_fetch_hook', 'jefrss_execute_fetch_task');

// 在 WordPress 初始化时尽早启动全局输出缓冲
function jefrss_simple_start_ob() {
    // 只在管理区域启动
    if (is_admin() && isset($_GET['page']) && strpos($_GET['page'], 'jefrss-simple') === 0) {
        ob_start();
    }
}
add_action('init', 'jefrss_simple_start_ob', 1); // 优先级设为1，尽早执行

// 在管理页面底部清除缓冲
function jefrss_simple_end_ob() {
    // 只在管理区域清除
    if (is_admin() && isset($_GET['page']) && strpos($_GET['page'], 'jefrss-simple') === 0) {
        if (ob_get_level()) {
            ob_end_flush();
        }
    }
}
add_action('admin_footer', 'jefrss_simple_end_ob', 999); // 优先级设为999，尽晚执行

// 禁用 WordPress 的 Web 字体加载功能
function jefrss_disable_wp_font_face() {
    // 只在管理页面禁用
    if (is_admin() && isset($_GET['page']) && strpos($_GET['page'], 'jefrss-simple') === 0) {
        remove_action('wp_head', 'wp_font_face_load_preload_tags', 1);
        remove_action('admin_head', 'wp_font_face_load_preload_tags', 1);
    }
}
add_action('init', 'jefrss_disable_wp_font_face', 1);